@@ -1,5 +1,3 @@
-context("pls classification models")
-
 library(tibble)
 library(modeldata)
 library(mixOmics)
@@ -15,7 +13,7 @@ x_vars <- c("bill_length_mm", "bill_depth_mm", "flipper_length_mm", "body_mass_g
 x_tr <- penguins[-for_test, x_vars]
 x_te <- penguins[ for_test, x_vars]
 
-uni_model  <- mixOmics::plsda(x_tr, y_tr, ncomp = 3)
+uni_model <- mixOmics::plsda(x_tr, y_tr, ncomp = 3)
 
 # ------------------------------------------------------------------------------
 
@@ -26,7 +24,7 @@ pls_spec <-
 
 # ------------------------------------------------------------------------------
 
-test_that('classification model fitting', {
+test_that("classification model fitting", {
   # Failures on r-devel are upstream in mixOmics. See
   # https://github.com/mixOmicsTeam/mixOmics/issues/162
   skip_on_cran()
@@ -48,7 +46,7 @@ test_that('classification model fitting', {
     regexp = NA
   )
 
-  uni_model_pred <- predict(uni_model, x_te)$class$mahalanobis.dist[,3]
+  uni_model_pred <- predict(uni_model, x_te)$class$mahalanobis.dist[, 3]
   uni_model_pred <- unname(uni_model_pred)
   uni_model_pred <- factor(uni_model_pred, levels = levels(penguins$species))
 
@@ -60,7 +58,7 @@ test_that('classification model fitting', {
     regexp = NA
   )
 
-  uni_model_pred <- predict(uni_model, x_te)$predict[,,3]
+  uni_model_pred <- predict(uni_model, x_te)$predict[, , 3]
   uni_model_pred <- tibble::as_tibble(uni_model_pred)
   names(uni_model_pred) <- paste0(".pred_", names(uni_model_pred))
 
@@ -77,13 +75,15 @@ test_that('classification model fitting', {
   expect_equal(nrow(parsnip_pls_da_class_mp$.pred[[1]]), 2)
   expect_equal(
     names(parsnip_pls_da_class_mp$.pred[[1]]),
-    c('num_comp', '.pred_class')
+    c("num_comp", ".pred_class")
   )
 
-  mo_pls_pred_9 <- predict(uni_model, x_te)$class$mahalanobis.dist[9,2:3]
+  mo_pls_pred_9 <- predict(uni_model, x_te)$class$mahalanobis.dist[9, 2:3]
   mo_pls_pred_9 <-
-    tibble(num_com = 2:3,
-           .pred_class = factor(mo_pls_pred_9, levels = levels(penguins$species)))
+    tibble(
+      num_com = 2:3,
+      .pred_class = factor(mo_pls_pred_9, levels = levels(penguins$species))
+    )
 
   expect_equivalent(
     as.data.frame(parsnip_pls_da_class_mp$.pred[[9]]),
@@ -95,31 +95,34 @@ test_that('classification model fitting', {
 
   expect_error(
     parsnip_pls_da_prob_mp <-
-      multi_predict(parsnip_pls_da,
-                    as.data.frame(x_te),
-                    type = "prob",
-                    num_comp = 2:3),
+      multi_predict(
+        parsnip_pls_da,
+        as.data.frame(x_te),
+        type = "prob",
+        num_comp = 2:3
+      ),
     regexp = NA
   )
   expect_equal(nrow(parsnip_pls_da_prob_mp), nrow(x_te))
   expect_equal(nrow(parsnip_pls_da_prob_mp$.pred[[1]]), 2)
   expect_equal(
     names(parsnip_pls_da_prob_mp$.pred[[1]]),
-    c('num_comp', paste0(".pred_", levels(penguins$species)))
+    c("num_comp", paste0(".pred_", levels(penguins$species)))
   )
 
-  mo_pls_pred_9 <- predict(uni_model, x_te)$predict[9,,2:3]
+  mo_pls_pred_9 <- predict(uni_model, x_te)$predict[9, , 2:3]
   mo_pls_pred_9 <- t(apply(mo_pls_pred_9, 2, plsmod:::smax))
   mo_pls_pred_9 <- as.data.frame(mo_pls_pred_9)
   mo_pls_pred_9 <-
-    tibble(num_com = 2:3,
-           .pred_setosa = mo_pls_pred_9$Adelie,
-           .pred_versicolor = mo_pls_pred_9$Chinstrap,
-           .pred_virginica = mo_pls_pred_9$Gentoo)
+    tibble(
+      num_com = 2:3,
+      .pred_setosa = mo_pls_pred_9$Adelie,
+      .pred_versicolor = mo_pls_pred_9$Chinstrap,
+      .pred_virginica = mo_pls_pred_9$Gentoo
+    )
 
   expect_equivalent(
     as.data.frame(parsnip_pls_da_prob_mp$.pred[[9]]),
     as.data.frame(mo_pls_pred_9)
   )
-
 })
